var path = require('path')
var webpack = require('webpack')
var fs = require('fs')
var utils = require('./build/utils')
var CopyWebpackPlugin = require('copy-webpack-plugin')
var HtmlWebpackPlugin = require('html-webpack-plugin');
var HtmlWebpackExcludeAssetsPlugin = require('html-webpack-exclude-assets-plugin');
var HtmlWebpackIncludeAssetsPlugin = require('html-webpack-include-assets-plugin');

/*添加逻辑   可以修改 public path */

var webpackProjectConfig = {
    webpack: {},
    mobileConfig:{},
    adminConfig:{},
    mobileAdvance:{},
    adminAdvance:{}
}
if (fs.existsSync(path.resolve(__dirname, './src/project.conf.json'))) {
    var projectConfig = require('./src/project.conf.json')
    if (projectConfig.webpack) {
        if (projectConfig.webpack.DIST_PATH) {

            webpackProjectConfig.webpack.DIST_PATH = projectConfig.webpack.DIST_PATH || ''
        }
        if (projectConfig.webpack.SERVER) {

            webpackProjectConfig.webpack.SERVER = projectConfig.webpack.SERVER || ''
        }
    }
}
if (fs.existsSync(path.resolve(__dirname, './src/app.json'))) {
    var mobileJson = require('./src/app.json')
    webpackProjectConfig.mobileConfig = mobileJson||{}
    if (mobileJson.advance) {
        webpackProjectConfig.mobileAdvance = mobileJson.advance||{}
    }
}
if (fs.existsSync(path.resolve(__dirname, './src/app-admin.json'))) {
    var adminJson = require('./src/app-admin.json')
    webpackProjectConfig.adminConfig = adminJson||{}
    if (adminJson.advance) {
        webpackProjectConfig.adminAdvance = adminJson.advance||{}
    }
}

//end of /*添加逻辑   可以修改 public path */

var vueLoaderConfig = require('./build/vue-loader.conf')


console.log("server->", process.env.SERVER || webpackProjectConfig.webpack.SERVER || '')
console.log("output dist->", process.env.DIST_PATH || webpackProjectConfig.webpack.DIST_PATH || '/dist/')

module.exports = {
    entry: {
        mobile: './src/main.js',
        admin: './src/main-admin.js'
    },
    resolve: {
        alias: {
            vue: 'vue/dist/vue.js',
            plugins: path.resolve(__dirname, './src/plugins'),
            layouts: path.resolve(__dirname, './src/layouts'),
            components: path.resolve(__dirname, './src/components'),
            vueroot: path.resolve(__dirname, './src'),
            webpackroot: path.resolve(__dirname, './'),
            externalcomponents: path.resolve(__dirname, './src/component'),
            externalmixins: path.resolve(__dirname, './src/mixins')
        }
    },
    output: {
        path: path.resolve(__dirname, './dist'),
        publicPath: process.env.DIST_PATH || webpackProjectConfig.webpack.DIST_PATH || '/dist/',
        filename: '[name].build.js?t=[hash]',
        chunkFilename: "[id].peach.js?t=[hash]"
    },
    resolveLoader: {
        root: path.join(__dirname, 'node_modules'),
    },
    module: {
        exprContextCritical: false,
        "presets": ["es2015"],
        loaders: [{
            test: /\.json$/,
            loader: 'json'
        },
        {
            test: /\.vue$/,
            loader: 'vue',
            options: vueLoaderConfig
        },
        {
            test: /\.js$/,
            loader: 'babel',
            exclude: /node_modules/
        },
        {
            test: /\.(css|less)$/,
            loader: "style-loader!css-loader!postcss-loader!less-loader"
        },
        {
            test: /\.(png|jpg|gif|svg|woff|ttf)$/i,
            loader: 'file?name=[path][name].[ext]?[hash]'
        }
        ]
    },
    devServer: {
        historyApiFallback: true,
        noInfo: true
    },
    devtool: '#eval-source-map',
    plugins: [
        new CopyWebpackPlugin([
            {
                from: 'src',
                to: 'src',
                ignore: [
                    '*.json',
                    '*.vue',
                    '*main.js',
                    '*main-admin.js'
                ]
            }, {
                from: 'assets',
                to: 'assets'
            }
        ]),
        new HtmlWebpackPlugin({
            hash:true,
            title: webpackProjectConfig.mobileConfig.window?(webpackProjectConfig.mobileConfig.window.navigationBarTitleText||"wevue mobile"):"wevue mobile",
            template: "template/index.html",
            server:(process.env.SERVER || webpackProjectConfig.webpack.SERVER || '').replace(/;/g,':'),
            filename: 'index.html',
            excludeAssets: [ new RegExp(process.env.DIST_PATH || webpackProjectConfig.webpack.DIST_PATH || '/dist/' + "[admin|index].build.js","i")]
        }),
        new HtmlWebpackPlugin({
            hash:true,
            title: webpackProjectConfig.adminConfig.window?(webpackProjectConfig.adminConfig.window.navigationBarTitleText||"wevue admin"):"wevue admin",
            template: 'template/admin.html',
            server:(process.env.SERVER || webpackProjectConfig.webpack.SERVER || '').replace(/;/g,':'),
            filename: 'admin.html',
            excludeAssets: [ new RegExp(process.env.DIST_PATH || webpackProjectConfig.webpack.DIST_PATH || '/dist/' + "[admin|index].build.js","i")]
        }),
        new HtmlWebpackPlugin({
            title: 'NOT FOUND',
            server:(process.env.SERVER || webpackProjectConfig.webpack.SERVER || '').replace(/;/g,':'),
            template: 'template/404.html',
            filename: '404.html',
            excludeAssets: [/.*build.js/]
        }),
        new HtmlWebpackExcludeAssetsPlugin(),
        new HtmlWebpackIncludeAssetsPlugin({
            files: ['index.html'],
            assets: utils.getAssetsList(webpackProjectConfig.mobileAdvance,'mobile'),
            append: true,
            hash:true,
            publicPath:false
        }),
        new HtmlWebpackIncludeAssetsPlugin({
            files: ['admin.html'],
            assets: utils.getAssetsList(webpackProjectConfig.adminAdvance,'admin'),
            append: true,
            hash:true,
            publicPath:false
        })
    ]
}
if (process.env.NODE_ENV === 'production') {
    module.exports.devtool = '#source-map'
    module.exports.plugins = (module.exports.plugins || []).concat([
        new webpack.DefinePlugin({
            'process.env': {
                NODE_ENV: '"production"'
            }
        }),
        new webpack.optimize.UglifyJsPlugin({
            compress: {
                warnings: false
            }
        }),
        new webpack.optimize.OccurenceOrderPlugin()
    ])
}
